==> arphound-1.3.1.tar.gz: arphound-1.3.1/shared/bsocket_l.h <==
/* bsocket_l.h
 *
 * Copyright (C) 2002 Matthieu Nottale <matthieu@nottale.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: bsocket_l.h,v 1.2 2003/10/02 19:29:56 cos Exp $
 *
 */
/******************************************************************
 *                  IRCSocket - Light version                     *
 *****************************************************************/

#ifndef IRCSocketH
#define IRCSocketH
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/types.h>

class bSocket;

typedef void (*tOnConnect )(bSocket * Waiting,bSocket * Connected);
typedef void (*tOnReceive )(bSocket * bSock,void * buff,unsigned long len);
typedef void (*tOnError   )(bSocket * bSock,unsigned long Error);

class bSocket
{
 private:
  unsigned long Online;
  int InternalSocket;
  void * CallBack;
  tOnError OnError;
  sockaddr_in Destination;
  bool UDP;
  bool InternalSend(const char *Buffer, unsigned long Len);

 public:
  unsigned long UserTag; // pas utilis, mais utilisable par autres
  bSocket(bool UDP=false);
  ~bSocket();
  bool Connect(char *HostName,int Port,char * interface=NULL);
  bool Disconnect();
  bool IsOnline() {return Online;};
  unsigned long Receive(char *Buffer,unsigned long MaxLen);
  unsigned long Send(const char *Source,unsigned long Len);
  unsigned long SlowSend(const char * source,unsigned long len);
  unsigned long Send(const char *Source);
  void GetLocalIp(char *ip); // renvoit l'ip locale d'une sock
  bool bSocket::Bind(int Port,char * interface=NULL); // a faire avant createrecvloop udp
  // boucle creee dans un nouveau thread, cree une nouvelle
  // bsocket a chaque connection sur le port, et appelle OnConnect
  // attention, 0nConnect doit retourner RAPIDEMENT pour liberer le thread
  bool CreateWaitLoop(int Port,tOnConnect OnConnect,tOnError OnError=NULL);
  bool StopWaitLoop();
  // la boucle tourne dans son propre thread
  bool CreateReceiveLoop(tOnReceive OnReceive,tOnError OnError=NULL);
  bool StopReceiveLoop();
  void WaitLoop();
  void ReceiveLoop();
  bool GetDestination(char * Buffer);
};

#endif

==> arphound-1.3.2.tar.gz: arphound-1.3.2/shared/bsocket_l.h <==
/* bsocket_l.h
 *
 * Copyright (C) 2002 Matthieu Nottale <matthieu@nottale.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: bsocket_l.h,v 1.2 2003/10/02 19:29:56 cos Exp $
 *
 */
/******************************************************************
 *                  IRCSocket - Light version                     *
 *****************************************************************/

#ifndef IRCSocketH
#define IRCSocketH
#include <arpa/inet.h>
#include <netdb.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/types.h>

class bSocket;

typedef void (*tOnConnect )(bSocket * Waiting,bSocket * Connected);
typedef void (*tOnReceive )(bSocket * bSock,void * buff,unsigned long len);
typedef void (*tOnError   )(bSocket * bSock,unsigned long Error);

class bSocket
{
 private:
  unsigned long Online;
  int InternalSocket;
  void * CallBack;
  tOnError OnError;
  sockaddr_in Destination;
  bool UDP;
  bool InternalSend(const char *Buffer, unsigned long Len);

 public:
  unsigned long UserTag; // pas utilis, mais utilisable par autres
  bSocket(bool UDP=false);
  ~bSocket();
  bool Connect(char *HostName,int Port,char * interface=NULL);
  bool Disconnect();
  bool IsOnline() {return Online;};
  unsigned long Receive(char *Buffer,unsigned long MaxLen);
  unsigned long Send(const char *Source,unsigned long Len);
  unsigned long SlowSend(const char * source,unsigned long len);
  unsigned long Send(const char *Source);
  void GetLocalIp(char *ip); // renvoit l'ip locale d'une sock
  bool Bind(int Port,char * interface=NULL); // a faire avant createrecvloop udp
  // boucle creee dans un nouveau thread, cree une nouvelle
  // bsocket a chaque connection sur le port, et appelle OnConnect
  // attention, 0nConnect doit retourner RAPIDEMENT pour liberer le thread
  bool CreateWaitLoop(int Port,tOnConnect OnConnect,tOnError OnError=NULL);
  bool StopWaitLoop();
  // la boucle tourne dans son propre thread
  bool CreateReceiveLoop(tOnReceive OnReceive,tOnError OnError=NULL);
  bool StopReceiveLoop();
  void WaitLoop();
  void ReceiveLoop();
  bool GetDestination(char * Buffer);
};

#endif
